vcs

package
v0.3.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 11, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package vcs returns the application version derived from embedded VCS build info. If the working tree was modified at build time, "_dirty" is appended.

Index

Constants

This section is empty.

Variables

var Modified string
var Revision string

Revision and Modified can be set at build time via ldflags:

-X github.com/rhemvi/omaclip/foundation/vcs.Revision=$(git rev-parse --short HEAD)
-X github.com/rhemvi/omaclip/foundation/vcs.Modified=$(git diff --quiet && echo false || echo true)

Functions

func Version

func Version(appVersion string) string

Types

This section is empty.

Jump to